hdfs3
=====

|Build Status|

hdfs3 is a lightweight Python wrapper for libhdfs3_, a native C/C++ library to interact with the Hadoop File System (HDFS).

View the documentation_ for hdfs3.

.. _libhdfs3: https://github.com/ContinuumIO/libhdfs3-downstream/tree/master/libhdfs3
.. _documentation: https://hdfs3.readthedocs.io/en/latest/

.. |Build Status| image:: https://travis-ci.org/dask/hdfs3.svg?branch=master
    :target: https://travis-ci.org/dask/hdfs3
